#import <Foundation/Foundation.h>
#include <stdio.h>
#include "a.h"
#include "b.h"

int main() { NSLog(@"%d %d", from_a_library, from_b_library); }
